# nanohttp

A very micro HTTP framework. [documentation](http://nanohttp.org)

[![PyPI](http://img.shields.io/pypi/v/nanohttp.svg)](https://pypi.python.org/pypi/nanohttp)
[![Gitter](https://badges.gitter.im/Carrene/nanohttp.svg)](https://gitter.im/Carrene/nanohttputm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://travis-ci.org/Carrene/nanohttp.svg?branch=master)](https://travis-ci.org/Carrene/nanohttp)
[![Coverage Status](https://coveralls.io/repos/github/Carrene/nanohttp/badge.svg?branch=master)](https://coveralls.io/github/Carrene/nanohttp?branch=master)


## Contribution


### Branching

A new branching model is applied to this repository, which consists of a 
master branch and release branches.

#### Master branch

The master branch is an integration branch where bug fixes/features are 
gathered for compiling and functional testing.

#### Release branch

The release branch is where releases are maintained and hot fixes 
(with names like release/v2.x.x) are added. Please ensure that all your 
production-related work are tracked with the release branches.

With this new model, we can push out bug fixes more quickly and achieve 
simpler maintenance.


